@@ -1,10 +1,6 @@
 package WWW::DME;
-BEGIN {
-  $WWW::DME::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $WWW::DME::VERSION = '0.001';
-}
+our $VERSION = '0.100';
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Shorter package name for accessing DNSMadeEasy API
 
 use Moo;
@@ -12,24 +8,24 @@ extends 'WWW::DNSMadeEasy';
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WWW::DME - Shorter package name for accessing DNSMadeEasy API
 
 =head1 VERSION
 
-version 0.001
+version 0.100
 
 =head1 DESCRIPTION
 
 See L<WWW::DNSMadeEasy>
 
-=encoding utf8
-
 =head1 SUPPORT
 
 IRC
@@ -45,16 +41,29 @@ Issue Tracker
 
   http://github.com/Getty/p5-www-dnsmadeeasy/issues
 
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/Getty/p5-www-dnsmadeeasy>
+
+  git clone https://github.com/Getty/p5-www-dnsmadeeasy.git
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudssus.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by L<Raudssus Social Software|http://www.raudssus.de/>.
+This software is copyright (c) 2012 by L<Torsten Raudssus|https://raudssus.de/>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
